<?php

namespace Drupal\graphviz_filter\Element;

use Drupal\Core\Render\Element\RenderElement;

/**
 * Provides a render element for a map tag, with properties and value.
 *
 * Properties:
 * - #children: (array, optional) The HTML <area> elements that define the
 *   hot-spot regions.
 * - #attributes: (array, optional) HTML attributes to apply to the tag. The
 *   attributes are escaped, see \Drupal\Core\Template\Attribute.
 *
 * Usage example:
 *
 * @code
 * $build['hello'] = [
 *   '#type' => 'map_tag',
 *   '#children => '<area shape="rect" id="node1" href="/node/1" title="Node 1" alt="" coords="5,1445,197,1493" />
 *   '#attributes' => [
 *     'id' => 'hello',
 *   ],
 * ];
 * @endcode
 *
 * @RenderElement("map_tag")
 */
class MapTag extends RenderElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    return [
      '#theme' => 'map_tag',
      '#children' => '',
      '#attributes' => [],
    ];
  }

}
