<?php

namespace Drupal\graphviz_filter\Plugin\FilterFormat;

use Drupal\Core\Annotation\Translation;
use Drupal\graphviz_filter\Plugin\Filter\FilterGraphviz;
use Drupal\graphviz_filter\Plugin\FilterFormat\FilterFormatBase;

/**
 * SVG filter format.
 *
 * @FilterFormat(
 *  id = "svg",
 *  label = @Translation("SVG (Scalable Vector Graphics)"),
 *  description = @Translation("SVG rendering using <object> embedding or the ZGRViewer applet (http://zvtm.sourceforge.net/zgrviewer/applet/)."),
 *  arguments = {
 *    "zgrviewer" = {
 *      "description" = @Translation("Render SVG using the ZGRViewer applet (TRUE or FALSE)."),
 *      "value" = FALSE
 *    }
 *  }
 * )
 */
class SvgFilterFormat extends FilterFormatBase {

  /**
   * {@inheritdoc}
   */
  public function render($destination, $format_destination, $filename, $format, array $arguments) {
    $outurl = file_create_url($format_destination);
    $modurl = url(drupal_get_path('module', 'graphviz_formats'), array('absolute' => TRUE));
    if ($arguments['zgrviewer']['value']) {
      return <<<EOS

<applet code="net.claribole.zgrviewer.ZGRApplet.class" archive="$modurl/zvtm.jar,$modurl/zgrviewer.jar" width="720" height="480">  
  <param name="type" value="application/x-java-applet;version=1.4" />  
  <param name="scriptable" value="false" />  
  <param name="width" value="720" />  
  <param name="height" value="480" />  
  <param name="svgURL" value="$outurl" />  
  <param name="title" value="" />  
  <param name="appletBackgroundColor" value="#DDD" />  
  <param name="graphBackgroundColor" value="#DDD" />  
  <param name="highlightColor" value="red" />
  <param name="displayOverview" value="true" />
</applet>

EOS;
    }
    else {
      return <<<EOS

<object type="image/svg+xml" data="$outurl">
  <embed type="image/svg+xml" src="$outurl" pluginspage="http://www.adobe.com/svg/viewer/install/" />
</object>

EOS;
    }
  }

}
